# plain.email

**Everything you need to send email in Plain.**

- [Installation](#installation)

## Installation

Install the `plain.email` package from [PyPI](https://pypi.org/project/plain.email/):

```bash
uv add plain.email
```

Add `plain.email` to your `INSTALLED_PACKAGES`:

```python
# settings.py
INSTALLED_PACKAGES = [
    # ...
    "plain.email",
]
```
